wcschr

Function wcschr 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn wcschr( ws: *const wchar_t, wc: wchar_t, ) -> *mut wchar_t
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/wcschr.html.

Safety

The caller is required to ensure that ws is a valid pointer to a buffer containing at least one nul value. The pointed-to buffer must not be modified for the duration of the call.